<?php
if( ! class_exists( 'WP_List_Table' ) ) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

/**
 * Ad_Goups_Table_WPTO class.
 *
 * @extends WP_List_Table
 */
class Ad_Goups_Table_WPTO extends WP_List_Table {

	/**
	 * example_data
	 *
	 * (default value: array())
	 *
	 * @var array
	 * @access public
	 */
	var $example_data = array();

	/**
	 * __construct function.
	 *
	 * @access public
	 * @return void
	 */
	function __construct(){
		global $status, $page;
        parent::__construct();
    }

	/**
	 * set_data function.
	 *
	 * @access public
	 * @param array $example_data (default: array())
	 * @return void
	 */
	function set_data( $example_data=array() ) {
		$this->example_data = $example_data;
	}

	/**
	 * no_items function.
	 *
	 * @access public
	 * @return void
	 */
	function no_items() {
		_e( 'No ad group found.' );
	}

	/**
	 * column_default function.
	 *
	 * @access public
	 * @param mixed $item
	 * @param mixed $column_name
	 * @return void
	 */
	function column_default( $item, $column_name ) {
		switch( $column_name ) {
			case 'name':
			case 'notes':
				return $item[ $column_name ];
			default:
				return print_r( $item, true ) ; //Show the whole array for troubleshooting purposes
		}
	}

	/**
	 * get_columns function.
	 *
	 * @access public
	 * @return void
	 */
	function get_columns(){
		$columns = array(
			//'cb'   => '<input type="checkbox" />',
			'name' 	=> __( 'Name', 'adgrouptable' ),
			'notes' => __( 'Description', 'adgrouptable' ),
		);
		return $columns;
	}

	/**
	 * column_name function.
	 *
	 * @access public
	 * @param mixed $item
	 * @return void
	 */
	function column_name($item) {

		$actions = array(
			'edit_1'	=> sprintf('<a class="btn btn-primary btn-xs" href="?page=ad-groups-wpto&action=edit&adgroup_id=%s">Edit</a>', isset($item['id']) ? $item['id'] : ''),
			'edit_2' 	=> sprintf('<a class="btn btn-danger btn-xs delete_btn" data-toggle="modal" data-target="#myModal" href="#" data-id="%s" data-url="?page=ad-groups-wpto&action=delete&adgroup_id=%s&adgroup_name=%s">Delete</a>', isset($item['name']) ? $item['name'] : '', isset($item['id']) ? $item['id'] : '', $item['name'])
		);

		return sprintf('%1$s %2$s', isset($item['name']) ? $item['name'] : null, $this->row_actions($actions) );
	}

	/**
	 * usort_reorder function.
	 *
	 * @access public
	 * @param mixed $a
	 * @param mixed $b
	 * @return void
	 */
	function usort_reorder( $a, $b ) {
		// If no sort, default to title
		$orderby = ( ! empty( $_GET['orderby'] ) ) ? $_GET['orderby'] : 'name';
		// If no order, default to asc
		$order = ( ! empty($_GET['order'] ) ) ? $_GET['order'] : 'asc';
		// Determine sort order
		$result = strcmp( $a[$orderby], $b[$orderby] );
		// Send final sort direction to usort
		return ( $order === 'asc' ) ? $result : -$result;
	}

	/**
	 * prepare_items function.
	 *
	 * @access public
	 * @return void
	 */
	function prepare_items() {
		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = $this->get_sortable_columns();
		$this->_column_headers = array( $columns, $hidden, $sortable );
		if (isset($this->example_data) && $this->example_data) usort( $this->example_data, array( &$this, 'usort_reorder' ) );

		$per_page = 10;
		$current_page = $this->get_pagenum();
		if (isset($this->example_data) && $this->example_data) $total_items = count( $this->example_data );

		// only ncessary because we have sample data
		if (isset($this->example_data) && $this->example_data) $this->example_data = array_slice( $this->example_data,( ( $current_page-1 )* $per_page ), $per_page );

		$this->set_pagination_args(array(
			'total_items' => isset($total_items) ? $total_items : 0,                  //WE have to calculate the total number of items
			'per_page'    => $per_page                     //WE have to determine how many items to show on a page
		));
		$this->items = isset($this->example_data) ? $this->example_data : array();
	}

	/**
	 * Get a list of CSS classes for the <table> tag
	 *
	 * @since 3.1.0
	 * @access protected
	 *
	 * @return array
	 */
	public function get_table_classes() {
	    return array('table table-striped table-responsive');
	}

	/**
	 * Display the table
	 *
	 * @since 3.1.0
	 * @access public
	 */
	public function display() {
		$singular = $this->_args['singular'];

		$this->display_tablenav( 'top' );

		?>
		<table class="<?php echo implode( ' ', $this->get_table_classes() ); ?>">
			<thead>
			<tr>
				<?php $this->print_column_headers(); ?>
			</tr>
			</thead>

			<tfoot>
			<tr>
				<?php $this->print_column_headers( false ); ?>
			</tr>
			</tfoot>

			<tbody id="the-list"<?php
				if ( $singular ) {
					echo " data-wp-lists='list:$singular'";
				} ?>>
				<?php $this->display_rows_or_placeholder(); ?>
			</tbody>
		</table>
		<?php
		$this->display_tablenav( 'bottom' );
	}

	/**
	 * Generate row actions div
	 *
	 * @since 3.1.0
	 * @access protected
	 *
	 * @param array $actions The list of actions
	 * @param bool $always_visible Whether the actions should be always visible
	 * @return string
	 */
	protected function row_actions( $actions, $always_visible = false ) {

		$action_count = count( $actions );
		$i = 0;

		if ( !$action_count )
			return '';

		$out = '<div class="' . ( $always_visible ? 'row-actions visible' : 'row-actions' ) . '">';
		foreach ( $actions as $action => $link ) {
			++$i;
			( $i == $action_count ) ? $sep = '' : $sep = ' | ';
			$out .= "<span class='$action'>$link$sep</span>";
		}
		$out .= '</div>';

		return $out;
	}

	/**
	 * Generates and display row actions links for the list table.
	 *
	 * @since 4.3.0
	 * @access protected
	 *
	 * @param object $item        The item being acted upon.
	 * @param string $column_name Current column name.
	 * @param string $primary     Primary column name.
	 * @return string The row actions output. In this case, an empty string.
	 */
	protected function handle_row_actions( $item, $column_name, $primary ) {
		return '';
 	}

} //class
?>